--
-- JohnDeere630R
-- Specialization for JohnDeere630R
--
-- @author      Karol Gruszczyk (MySQly)
-- @version     v1.0
-- @date        11/01/17
-- @history:    v1.0 - Initial version
--

JohnDeere630R = {}

function JohnDeere630R.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Foldable, specializations)
end

function JohnDeere630R:load(xmlFile)


    self.leftWheatSpikeCallback = SpecializationUtil.callSpecializationsFunction("leftWheatSpikeCallback")
    self.rightWheatSpikeCallback = SpecializationUtil.callSpecializationsFunction("rightWheatSpikeCallback")

    local leftWheatSpikeTrigger = Utils.indexToObject(self.components, getXMLString(self.xmlFile, string.format("vehicle.wheatSpikes#leftTriggerNode")))
    local rightWheatSpikeTrigger = Utils.indexToObject(self.components, getXMLString(self.xmlFile, string.format("vehicle.wheatSpikes#rightTriggerNode")))

    self.leftWheatSpikeAnim = getXMLString(self.xmlFile, "vehicle.wheatSpikes#leftAnimName")
    self.rightWheatSpikeAnim = getXMLString(self.xmlFile, "vehicle.wheatSpikes#rightAnimName")

    self.inLeftWheatSpikeTrigger = false
    self.inRightWheatSpikeTrigger = false

    self.leftWheatSpikeDir = 1
    self.rightWheatSpikeDir = 1

    addTrigger(leftWheatSpikeTrigger, "leftWheatSpikeCallback", self);
    addTrigger(rightWheatSpikeTrigger, "rightWheatSpikeCallback", self);
end

function JohnDeere630R:delete()
    removeTrigger(self.leftWheatSpikeTrigger)
    removeTrigger(self.rightWheatSpikeTrigger)
end

function JohnDeere630R:mouseEvent(posX, posY, isDown, isUp, button)
end

function JohnDeere630R:keyEvent(unicode, sym, modifier, isDown)
end

function JohnDeere630R:update(dt)

    if self.inLeftWheatSpikeTrigger then
        g_currentMission:addHelpButtonText(g_i18n:getText("SET_WHEATSPIKE"), InputBinding.SET_WHEATSPIKE);    
        setTextColor(1.0, 1.0, 1.0, 1.0);
        setTextAlignment(RenderText.ALIGN_LEFT);                 
        renderText(0.5, 0.06, 0.02, g_i18n:getText("SET_WHEATSPIKE"))
        if InputBinding.hasEvent(InputBinding.SET_WHEATSPIKE) then
            if self.inLeftWheatSpikeTrigger then
                self:playAnimation(self.leftWheatSpikeAnim, self.leftWheatSpikeDir, Utils.clamp(self:getAnimationTime(self.leftWheatSpikeAnim), 0, 1), true);
                self.leftWheatSpikeDir = -1 * self.leftWheatSpikeDir
            end
        end
    end
    if self.inRightWheatSpikeTrigger then
        g_currentMission:addHelpButtonText(g_i18n:getText("SET_WHEATSPIKE2"), InputBinding.SET_WHEATSPIKE2);    
        setTextColor(1.0, 1.0, 1.0, 1.0);
        setTextAlignment(RenderText.ALIGN_RIGHT);                 
        renderText(0.5, 0.06, 0.02, g_i18n:getText("SET_WHEATSPIKE2"))
        if InputBinding.hasEvent(InputBinding.SET_WHEATSPIKE2) then
            if self.inRightWheatSpikeTrigger then
                self:playAnimation(self.rightWheatSpikeAnim, self.rightWheatSpikeDir, Utils.clamp(self:getAnimationTime(self.rightWheatSpikeAnim), 0, 1), true);
                self.rightWheatSpikeDir = -1 * self.rightWheatSpikeDir
            end
        end
    end

    if self.attacherVehicle ~= nil then
        local vehicle = self.attacherVehicle
        if turnedOn and not rapeAttached and (self.leftWheatSpikeDir == 1 or self.rightWheatSpikeDir == 1) then
            if vehicle.isAIThreshing ~= nil then
                if vehicle.isAIThreshing then
                    vehicle:stopAIThreshing();
                end
            end
            vehicle:setIsTurnedOn(false)
            g_currentMission:showBlinkingWarning(g_i18n:getText("WHEATSPIKE_WARNING"), 2000)
        end
    end
end

function JohnDeere630R:updateTick(dt)
end

function JohnDeere630R:onTurnedOn()
end

function JohnDeere630R:onTurnedOff()
end

function JohnDeere630R:draw()
end

function JohnDeere630R:leftWheatSpikeCallback(triggerId, otherId, onEnter, onLeave, onStay)
    if onEnter and g_currentMission.controlPlayer and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
        self.inLeftWheatSpikeTrigger = true
    elseif onLeave and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
        self.inLeftWheatSpikeTrigger = false
    end
end

function JohnDeere630R:rightWheatSpikeCallback(triggerId, otherId, onEnter, onLeave, onStay)
    if onEnter and g_currentMission.controlPlayer and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
        self.inRightWheatSpikeTrigger = true
    elseif onLeave and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
        self.inRightWheatSpikeTrigger = false
    end
end
